@@ -1,5 +1,5 @@
 # Copyright 2011-2018 Rumma & Ko Ltd
-# License: BSD, see LICENSE for more details.
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 """
 This is the :mod:`atelier` package.
 
@@ -24,9 +24,9 @@ from .setup_info import SETUP_INFO
 
 __version__ = SETUP_INFO['version']
 
-intersphinx_urls = dict(docs="https://lino-framework.gitlab.io/atelier")
-srcref_url = 'https://github.com/lino-framework/atelier/blob/master/%s'
-doc_trees = ['docs']
+intersphinx_urls = dict(docs="https://atelier.lino-framework.org")
+srcref_url = 'https://gitlab.com/lino-framework/atelier/blob/master/%s'
+# doc_trees = ['docs']
 
 current_project = None
 """
