@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 # Copyright 2013-2021 Rumma & Ko Ltd
-# License: BSD, see LICENSE for more details.
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 """
 This is the module that defines the invoke namespace.
 
@@ -36,6 +36,19 @@ from atelier.utils import confirm, cd
 
 from .utils import must_confirm
 
+import requests
+
+def checkurl(url, name):
+    r = requests.get(url, allow_redirects=False)
+    if r.status_code != 200:
+        print("{name} ({url}) returns {r.status_code}".format(**locals()))
+
+def add_slash(url):
+    if not url.endswith('/'):
+        url += "/"
+    return url
+
+
 LASTREL_INFO = "Last PyPI release was %(filename)s \
 (%(upload_time)s,  %(downloads)d downloads)."
 
@@ -69,8 +82,19 @@ def get_current_date(today=None):
     return i2d(today)
 
 
+def set_times(pth):
+    """Set the timestamps of the specified file to now.
+
+    Same effect as running :cmd:`touch <pth>` in a shell.
+
+    """
+    mtime = time.time()
+    os.utime(pth, (mtime, mtime))
+
+
 def rmtree_after_confirm(p, batch=False):
     if not p.exists():
+        # print("20210425 does not exist:", str(p))
         return
     if batch or confirm(
             "OK to remove %s and everything under it?" % p.absolute()):
@@ -78,7 +102,7 @@ def rmtree_after_confirm(p, batch=False):
 
 
 def cleanup_pyc(p, batch=False):  # no longer used
-    """Thanks to oddthinking on http://stackoverflow.com/questions/2528283
+    """Thanks to oddthinking on https://stackoverflow.com/questions/2528283
     """
     for root, dirs, files in os.walk(p):
         pyc_files = [filename for filename in files if filename.endswith(".pyc")]
@@ -230,16 +254,16 @@ def build_docs(ctx, only=None):
     """Build docs. Build all Sphinx HTML doctrees for this project. """
     # print("Build docs for {}".format(atelier.current_project))
 
-    cmd = ctx.build_docs_command
-    if cmd:
-        print("-" * 80)
-        print("Run build_docs_command {0} :".format(cmd))
-        ctx.run(cmd, pty=True)
-    else:
-        for tree in atelier.current_project.get_doc_trees():
-            if tree.src_path:
-               if only is None or tree.rel_path == only:
-                    tree.build_docs(ctx)
+    # cmd = ctx.build_docs_command
+    # if cmd:
+    #     print("-" * 80)
+    #     print("Run build_docs_command {0} :".format(cmd))
+    #     ctx.run(cmd, pty=True)
+    # else:
+    for tree in atelier.current_project.get_doc_trees():
+        if tree.src_path:
+           if only is None or tree.rel_path == only:
+                tree.build_docs(ctx)
 
 
 @task(name='clean')
@@ -458,10 +482,12 @@ def edit_blog_entry(ctx, today=None):
             yd.mkdir()
             txt = ".. blogger_year::\n"
             (yd / 'index.rst').write_text(txt)
+            set_times(yd.parent / 'index.rst')
 
         entry.path.write_text(content)
-        # touch it for Sphinx:
-        # (entry.path.parent / 'index.rst').set_times()
+        # touch the year's index for Sphinx:
+        set_times(entry.path.parent / 'index.rst')
+
     args = [ctx.editor_command.format(entry.path)]
     args += [str(entry.path)]
     # raise Exception("20160324 %s", args)
@@ -626,6 +652,61 @@ def git_projects():
             yield prj
 
 
+@task(name='check')
+def check_config(ctx):
+    """Check configuration integrity."""
+    from git import Repo
+    import giturlparse # pip install git-url-parse
+    prj = atelier.current_project
+    prj.load_info()
+    if prj.config['revision_control_system'] != 'git':
+        if (prj.root_dir / '.git').exists():
+            print("revision_control_system is not 'git', but .git directory exists")
+        return
+    info = prj.SETUP_INFO
+    if len(info) == 0:
+        # print("No SETUP_INFO")
+        return
+    repo = Repo(prj.root_dir)
+    p = giturlparse.parse(repo.remotes.origin.url)
+    origin = "https://{p.resource}/{p.owner}/{p.name}".format(p=p)
+    if not 'url' in info:
+        print("No url in SETUP_INFO (expected: {})".format(origin))
+        return
+    if info['url'] != origin:
+        print("url in SETUP_INFO ({}) differs from git origin {}".format(
+            info['url'], origin))
+    srcref_url = getattr(prj.main_package, 'srcref_url', None)
+    if srcref_url and not srcref_url.startswith(origin):
+        print("srcref_url of {} ({}) must start with git origin ({})".format(
+            prj.main_package, srcref_url, origin))
+
+    doc_trees = prj.get_xconfig('doc_trees')
+    intersphinx_urls = prj.get_xconfig('intersphinx_urls')
+    for dtname in doc_trees:
+        # public_url = add_slash(prj.get_public_docs_url(dtname))
+        if intersphinx_urls:
+            for k, url in intersphinx_urls.items():
+                checkurl(url, "intersphinx_urls['{}']".format(k))
+            # if public_url:
+            #     url2 = add_slash(intersphinx_urls[dtname])
+            #     if public_url != url2:
+            #         print("public_url ({}) differs from main intersphinx url ({})".format(
+            #             public_url, url2))
+    public_url = prj.get_public_docs_url('docs')
+    if not public_url and prj.config['selectable_languages']:
+        print("selectable_languages but no public_url")
+
+    url = prj.config.get('blogref_url', None)
+    if url:
+        r = requests.get(url, allow_redirects=False)
+        if r.status_code != 200:
+            print("blogref_url ({}) returns {}".format(url, r.status_code))
+
+
+
+
+
 @task(name='ct')
 def commited_today(ctx, today=None):
     """Print all today's commits to stdout."""
@@ -647,10 +728,7 @@ def commited_today(ctx, today=None):
 
     def load(prj):
 
-        # prj.load_info()
-        # repo = Repo(cfg['root_dir'])
         repo = Repo(prj.root_dir)
-
         it = list(repo.iter_commits(**list_options))
         if len(it) == 0:
             # print("20160816 no commits in {}".format(prj.nickname))
