@@ -1,5 +1,5 @@
 # Copyright 2013-2021 Rumma & Ko Ltd
-# License: BSD, see LICENSE for more details.
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 # This module has no docstring because it is to be execfile'd
 # from `setup.py`, `atelier/__init__.py` and possibly some external
@@ -7,13 +7,17 @@
 
 install_requires = ['invoke', 'argh', 'six',
                     'future', 'Babel',
-                    'python_dateutil', 'Sphinx', 'rstgen']
-install_requires.append('sphinx_rtd_theme')
+                    'python-dateutil', 'Sphinx', 'rstgen']
+install_requires.append('requests')
+install_requires.append('sphinx-panels')
+install_requires.append('sphinx-rtd-theme')
+install_requires.append('pydata-sphinx-theme')
+install_requires.append('insipid-sphinx-theme')
 # trying to fix #3246
 tests_require = ['gitpython', 'pytest-cov']
 
 # Explicitly install `importlib` under Python 2.6. Thanks to
-# http://stackoverflow.com/questions/9418064
+# https://stackoverflow.com/questions/9418064
 try:
     import importlib
 except ImportError:
@@ -21,16 +25,16 @@ except ImportError:
 
 SETUP_INFO = dict(
     name='atelier',
-    version='1.1.29',
+    version='1.1.31',
     install_requires=install_requires,
     tests_require=tests_require,
     scripts=['scripts/per_project'],
     description="A collection of tools for software artists",
-    license='BSD-2-Clause',
+    license_files=['COPYING'],
     test_suite='tests',
     author='Luc Saffre',
     author_email='luc@lino-framework.org',
-    url="https://lino-framework.gitlab.io/atelier",
+    url="https://gitlab.com/lino-framework/atelier",
     long_description="""\
 
 `atelier` is a collection of tools for managing and maintaining Python software
@@ -56,7 +60,7 @@ Programming Language :: Python :: 3.7
 Framework :: Sphinx :: Extension
 Development Status :: 5 - Production/Stable
 Intended Audience :: Developers
-License :: OSI Approved :: BSD License
+License :: OSI Approved :: GNU Affero General Public License v3
 Natural Language :: English
 Operating System :: OS Independent""".splitlines())
 
